@@ -88,6 +88,7 @@ public class Medialibrary {
         if (extFilesDir == null || !extFilesDir.exists()
                 || dbDirectory == null || !dbDirectory.canWrite())
             return ML_INIT_FAILED;
+        LibVLC.loadLibraries();
         int initCode = nativeInit(dbDirectory+ VLC_MEDIA_DB_NAME, extFilesDir+ THUMBS_FOLDER_NAME);
         mIsInitiated = initCode != ML_INIT_FAILED;
         return initCode;
@@ -99,12 +100,12 @@ public class Medialibrary {
 
     public void banFolder(@NonNull String path) {
         if (mIsInitiated && new File(path).exists())
-            nativeBanFolder(Tools.encodeVLCMrl(Uri.encode(path, "/")));
+            nativeBanFolder(Tools.encodeVLCMrl(path));
     }
 
     public void unbanFolder(@NonNull String path) {
         if (mIsInitiated && new File(path).exists())
-            nativeUnbanFolder(Tools.encodeVLCMrl(Uri.encode(path, "/")));
+            nativeUnbanFolder(Tools.encodeVLCMrl(path));
     }
 
     public String[] getDevices() {
@@ -121,9 +122,8 @@ public class Medialibrary {
     }
 
     public void removeFolder(@NonNull String mrl) {
-        if (!mIsInitiated)
-            return;
-        String[] folders = getFoldersList();
+        if (!mIsInitiated) return;
+        final String[] folders = getFoldersList();
         for (String folder : folders) {
             if (!folder.equals(mrl) && folder.contains(mrl))
                 removeFolder(folder);
@@ -191,8 +191,8 @@ public class Medialibrary {
     }
 
     @WorkerThread
-    public Artist[] getArtists() {
-        return mIsInitiated ? nativeGetArtists() : new Artist[0];
+    public Artist[] getArtists(boolean all) {
+        return mIsInitiated ? nativeGetArtists(all) : new Artist[0];
     }
 
     public Artist getArtist(long artistId) {
@@ -242,8 +242,11 @@ public class Medialibrary {
     }
 
     public void forceParserRetry() {
-        if (mIsInitiated)
-            nativeForceParserRetry();
+        if (mIsInitiated) nativeForceParserRetry();
+    }
+
+    public void forceRescan() {
+        if (mIsInitiated) nativeForceRescan();
     }
 
     @WorkerThread
@@ -271,13 +274,13 @@ public class Medialibrary {
 
     @Nullable
     public MediaWrapper getMedia(Uri uri) {
-        final String vlcMrl = Tools.encodeVLCMrl(uri.toString());
+        final String vlcMrl = Tools.encodeVLCMrl(Uri.decode(uri.toString()));
         return mIsInitiated && !TextUtils.isEmpty(vlcMrl) ? nativeGetMediaFromMrl(vlcMrl) : null;
     }
 
     @Nullable
     public MediaWrapper getMedia(String mrl) {
-        final String vlcMrl = Tools.encodeVLCMrl(mrl);
+        final String vlcMrl = Tools.encodeVLCMrl(Uri.decode(mrl));
         return mIsInitiated && !TextUtils.isEmpty(vlcMrl) ? nativeGetMediaFromMrl(vlcMrl) : null;
     }
 
@@ -639,7 +642,7 @@ public class Medialibrary {
     private native int nativeGetAudioCount();
     private native Album[] nativeGetAlbums();
     private native Album nativeGetAlbum(long albumtId);
-    private native Artist[] nativeGetArtists();
+    private native Artist[] nativeGetArtists(boolean all);
     private native Artist nativeGetArtist(long artistId);
     private native Genre[] nativeGetGenres();
     private native Genre nativeGetGenre(long genreId);
@@ -651,6 +654,7 @@ public class Medialibrary {
     private native void nativeReload();
     private native void nativeReload(String entryPoint);
     private native void nativeForceParserRetry();
+    private native void nativeForceRescan();
     private native boolean nativeIncreasePlayCount(long mediaId);
     private native void nativeSetMediaUpdatedCbFlag(int flags);
     private native void nativeSetMediaAddedCbFlag(int flags);
