@@ -43,6 +43,7 @@ import android.text.TextUtils;
 import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.medialibrary.Medialibrary;
 import org.videolan.vlc.gui.helpers.UiTools;
+import org.videolan.vlc.util.Constants;
 import org.videolan.vlc.util.Strings;
 import org.videolan.vlc.util.Util;
 
@@ -55,7 +56,7 @@ import java.util.List;
 
 public class ExternalMonitor extends BroadcastReceiver {
     public final static String TAG = "VLC/ExternalMonitor";
-    private static volatile boolean connected = true;
+    private static volatile boolean connected = false;
     private static volatile boolean mobile = true;
     private static volatile boolean vpn = false;
     private static final ExternalMonitor instance = new ExternalMonitor();
@@ -81,7 +82,7 @@ public class ExternalMonitor extends BroadcastReceiver {
 
     private static void checkNewStorages(final Context ctx) {
         if (VLCApplication.getMLInstance().isInitiated())
-            ctx.startService(new Intent(MediaParsingService.ACTION_CHECK_STORAGES, null,ctx, MediaParsingService.class));
+            ctx.startService(new Intent(Constants.ACTION_CHECK_STORAGES, null,ctx, MediaParsingService.class));
     }
 
     static void unregister(Context ctx) {
@@ -102,7 +103,7 @@ public class ExternalMonitor extends BroadcastReceiver {
                     cm = (ConnectivityManager) VLCApplication.getAppContext().getSystemService(
                             Context.CONNECTIVITY_SERVICE);
                 final NetworkInfo networkInfo = cm.getActiveNetworkInfo();
-                final boolean isConnected = networkInfo != null && networkInfo.isConnectedOrConnecting();
+                final boolean isConnected = networkInfo != null && networkInfo.isConnected();
                 mobile = isConnected && networkInfo.getType() == ConnectivityManager.TYPE_MOBILE;
                 vpn = isConnected && updateVPNStatus();
                 if (isConnected != connected) {
@@ -142,13 +143,13 @@ public class ExternalMonitor extends BroadcastReceiver {
                         if (!containsDevice(knownDevices, path) && ml.addDevice(uuid, path, true)) {
                             notifyStorageChanges(path);
                         } else {
-                            LocalBroadcastManager.getInstance(appCtx).sendBroadcast(new Intent(MediaParsingService.ACTION_SERVICE_ENDED));
+                            LocalBroadcastManager.getInstance(appCtx).sendBroadcast(new Intent(Constants.ACTION_SERVICE_ENDED));
                         }
                     }
                     break;
                 case ACTION_MEDIA_UNMOUNTED:
                     VLCApplication.getMLInstance().removeDevice(uuid);
-                    LocalBroadcastManager.getInstance(appCtx).sendBroadcast(new Intent(MediaParsingService.ACTION_SERVICE_ENDED));
+                    LocalBroadcastManager.getInstance(appCtx).sendBroadcast(new Intent(Constants.ACTION_SERVICE_ENDED));
                     break;
             }
         }
