@@ -187,7 +187,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
 
         // Make sure the audio player will acquire a wake-lock while playing. If we don't do
         // that, the CPU might go to sleep while the song is playing, causing playback to stop.
-        final PowerManager pm = (PowerManager) VLCApplication.getAppContext().getSystemService(Context.POWER_SERVICE);
+        final PowerManager pm = (PowerManager) getApplicationContext().getSystemService(Context.POWER_SERVICE);
         mWakeLock = pm.newWakeLock(PowerManager.PARTIAL_WAKE_LOCK, TAG);
 
         updateHasWidget();
@@ -287,7 +287,6 @@ public class PlaybackService extends MediaBrowserServiceCompat{
             mRemoteControlClientReceiver = null;
         }
         playlistManager.onServiceDestroyed();
-        updateWidget();
     }
 
     @Override
@@ -301,10 +300,10 @@ public class PlaybackService extends MediaBrowserServiceCompat{
 
     private final OnAudioFocusChangeListener mAudioFocusListener = createOnAudioFocusChangeListener();
 
+    private volatile boolean mLossTransient = false;
     private OnAudioFocusChangeListener createOnAudioFocusChangeListener() {
         return new OnAudioFocusChangeListener() {
             int audioDuckLevel = -1;
-            private boolean mLossTransient = false;
             private int mLossTransientVolume = -1;
             private boolean wasPlaying = false;
 
@@ -370,8 +369,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
                 if (mLossTransient) return;
                 mLossTransient = true;
                 wasPlaying = isPlaying();
-                if (wasPlaying)
-                    pause();
+                if (wasPlaying) pause();
             }
         };
     }
@@ -383,7 +381,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
         if (mAudioManager == null)
             return;
 
-        if (acquire) {
+        if (acquire && !hasRenderer()) {
             if (!mHasAudioFocus) {
                 final int result = mAudioManager.requestAudioFocus(mAudioFocusListener,
                         AudioManager.STREAM_MUSIC, AudioManager.AUDIOFOCUS_GAIN);
@@ -392,12 +390,10 @@ public class PlaybackService extends MediaBrowserServiceCompat{
                     mHasAudioFocus = true;
                 }
             }
-        } else {
-            if (mHasAudioFocus) {
-                mAudioManager.abandonAudioFocus(mAudioFocusListener);
-                mAudioManager.setParameters("bgm_state=false");
-                mHasAudioFocus = false;
-            }
+        } else if (mHasAudioFocus) {
+            mAudioManager.abandonAudioFocus(mAudioFocusListener);
+            mAudioManager.setParameters("bgm_state=false");
+            mHasAudioFocus = false;
         }
     }
 
@@ -662,7 +658,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
                                 mw.hasFlag(MediaWrapper.MEDIA_FORCE_AUDIO), title, artist, album,
                                 cover, playing, sessionToken, getSessionPendingIntent());
                         if (isPlayingPopup()) return;
-                        if (!AndroidUtil.isLolliPopOrLater || playing) {
+                        if (!AndroidUtil.isLolliPopOrLater || playing || mLossTransient) {
                             if (!mIsForeground) {
                                 PlaybackService.this.startForeground(3, notification);
                                 mIsForeground = true;
@@ -783,6 +779,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
 
         @Override
         public boolean onMediaButtonEvent(Intent mediaButtonEvent) {
+            if (!mSettings.getBoolean("enable_headset_actions", true) || VLCApplication.showTvUi()) return false;
             final KeyEvent event = mediaButtonEvent.getParcelableExtra(Intent.EXTRA_KEY_EVENT);
             if (event != null && !isVideoPlaying()) {
                 final int keyCode = event.getKeyCode();
@@ -832,10 +829,8 @@ public class PlaybackService extends MediaBrowserServiceCompat{
 
         @Override
         public void onPlay() {
-            if (hasMedia())
-                play();
-            else
-                loadLastAudioPlaylist();
+            if (hasMedia()) play();
+            else loadLastAudioPlaylist();
         }
 
         @Override
@@ -1770,6 +1765,8 @@ public class PlaybackService extends MediaBrowserServiceCompat{
         if (wasOnRenderer && !hasRenderer() && canSwitchToVideo()) VideoPlayerActivity.startOpened(VLCApplication.getAppContext(),
                 playlistManager.getCurrentMedia().getUri(), playlistManager.getCurrentIndex());
         playlistManager.getPlayer().setRenderer(item);
+        if (!wasOnRenderer && item != null) changeAudioFocus(false);
+        else if (wasOnRenderer && item == null && isPlaying()) changeAudioFocus(true);
     }
 
     @MainThread
