@@ -23,6 +23,7 @@
 
 package org.videolan.vlc.gui.browser;
 
+import android.support.annotation.MainThread;
 import android.view.View;
 import android.widget.CheckBox;
 
@@ -69,8 +70,6 @@ class StorageBrowserAdapter extends BaseBrowserAdapter {
         else
             vh.binding.browserCheckbox.setState(ThreeStatesCheckbox.STATE_UNCHECKED);
         vh.binding.setCheckEnabled(!((StorageBrowserFragment) fragment).mScannedDirectory);
-        if (hasContextMenu)
-            vh.setContextMenuListener();
     }
 
     private boolean hasDiscoveredChildren(String path) {
@@ -80,6 +79,7 @@ class StorageBrowserAdapter extends BaseBrowserAdapter {
         return false;
     }
 
+    @MainThread
     public void addItem(MediaLibraryItem item, boolean top, int position) {
         if (item.getItemType() == MediaLibraryItem.TYPE_MEDIA)
             item = new Storage(((MediaWrapper)item).getUri());
